| updateConfig | R Documentation |
Connects to the local DuckDB. Checks for missing comics and fetches full metadata (Title, Alt Text, Transcript) from the JSON API for any gaps.
updateConfig()
'TRUE', invisibly, if the database is successfully updated or determined to be up-to-date. The function will stop with an error if it cannot connect to 'xkcd.com'.
## Not run:
updateConfig()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.